Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(196)

Unified Diff: cc/layers/picture_layer_impl_unittest.cc

Issue 1126793002: cc: Make tiling interest rect calc based on viewport. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: use new settings for interest rect calc. Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/layers/picture_layer_impl_unittest.cc
diff --git a/cc/layers/picture_layer_impl_unittest.cc b/cc/layers/picture_layer_impl_unittest.cc
index f5702d32614d280e6e6bdbafdcf429166d17d2c5..6d7d622c0899bed0cc5f409197d2303a072f449e 100644
--- a/cc/layers/picture_layer_impl_unittest.cc
+++ b/cc/layers/picture_layer_impl_unittest.cc
@@ -2555,8 +2555,8 @@ TEST_F(PictureLayerImplTest, RequiredTilesWithGpuRasterization) {
active_layer_->HighResTiling()->UpdateAllTilePrioritiesForTesting();
- // High res tiling should have 64 tiles (4x16 tile grid).
- EXPECT_EQ(64u, active_layer_->HighResTiling()->AllTilesForTesting().size());
+ // High res tiling should have 36 tiles (4x9 tile grid).
vmpstr 2015/05/06 17:57:29 Can you verify manually that it is actually 4x9? I
sohanjg 2015/05/07 14:42:10 Hmm..for this test viewport is 1kX1k, tile size is
vmpstr 2015/05/07 17:21:38 There should be exactly 4 tiles in the viewport wh
sohanjg 2015/05/08 13:26:09 Yes, you are right. My mistake. The tile x,y does
+ EXPECT_EQ(36u, active_layer_->HighResTiling()->AllTilesForTesting().size());
// Visible viewport should be covered by 4 tiles. No other
// tiles should be required for activation.

Powered by Google App Engine
This is Rietveld 408576698